summaryrefslogtreecommitdiff
path: root/ubi-utils/include/libubi.h
diff options
context:
space:
mode:
authorArtem Bityutskiy <Artem.Bityutskiy@nokia.com>2010-06-15 13:03:14 +0300
committerArtem Bityutskiy <Artem.Bityutskiy@nokia.com>2010-06-15 13:04:54 +0300
commitccb2e466874c12fa060f9741f491bffa897a3a0c (patch)
tree27d7a18d7f284fb83d2c2f467f8876429ae32fb3 /ubi-utils/include/libubi.h
parentf64e613c4402080edf03c225cb4c0068040cf028 (diff)
ubi-utils: harmonize mtd device node variables
Consistently use 'mtd_dev_node' to name variables consining MTD device node path. Signed-off-by: Artem Bityutskiy <Artem.Bityutskiy@nokia.com>
Diffstat (limited to 'ubi-utils/include/libubi.h')
-rw-r--r--ubi-utils/include/libubi.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/ubi-utils/include/libubi.h b/ubi-utils/include/libubi.h
index ffc4be9..03b16ad 100644
--- a/ubi-utils/include/libubi.h
+++ b/ubi-utils/include/libubi.h
@@ -43,8 +43,8 @@ typedef void * libubi_t;
* @dev_num: number to assign to the newly created UBI device
* (%UBI_DEV_NUM_AUTO should be used to automatically assign the
* number)
* @mtd_num: MTD device number to attach (used if @dev is %NULL)
* @dev: path to MTD device node to attach
* @vid_hdr_offset: VID header offset (%0 means default offset and this is what
* most of the users want)
*/
@@ -52,7 +52,7 @@ struct ubi_attach_request
{
int dev_num;
int mtd_num;
- const char *dev;
+ const char *mtd_dev_node;
int vid_hdr_offset;
};
@@ -226,9 +226,9 @@ int ubi_attach_mtd(libubi_t desc, const char *node,
* @req: MTD attach request
*
* This function creates new UBI device by attaching an MTD device described by
* @req. If @req->dev is given it should contain path to the MTD device node.
* Otherwise functionality is similar than in function 'ubi_attach_mtd()' where
* @req->mtd_num is used.
*
* Returns %0 in case of success and %-1 in case of failure (errno is set). The
* newly created UBI device number is returned in @req->dev_num.
@@ -252,12 +252,12 @@ int ubi_detach_mtd(libubi_t desc, const char *node, int mtd_num);
* ubi_detach - detach an MTD device by its node path.
* @desc: UBI library descriptor
* @node: name of the UBI control character device node
* @dev: path to an MTD device node
*
* This function detaches an MTD device @dev from UBI. Returns zero in case of
* success and %-1 in case of failure.
*/
-int ubi_detach(libubi_t desc, const char *node, const char *dev);
+int ubi_detach(libubi_t desc, const char *node, const char *mtd_dev_node);
/**
* ubi_remove_dev - remove an UBI device.
@@ -43,8 +43,8 @@ typedef void * libubi_t;
* (%UBI_DEV_NUM_AUTO should be used to automatically assign the
* number)
- * @mtd_num: MTD device number to attach (used if @dev is %NULL)
- * @dev: path to MTD device node to attach
+ * @mtd_num: MTD device number to attach (used if @mtd_dev_node is %NULL)
+ * @mtd_dev_node: path to MTD device node to attach
* @vid_hdr_offset: VID header offset (%0 means default offset and this is what
* most of the users want)
@@ -226,9 +226,9 @@ int ubi_attach_mtd(libubi_t desc, const char *node,
*
* This function creates new UBI device by attaching an MTD device described by
- * @req. If @req->dev is given it should contain path to the MTD device node.
- * Otherwise functionality is similar than in function 'ubi_attach_mtd()' where
- * @req->mtd_num is used.
+ * @req. If @req->mtd_dev_node is given it should contain path to the MTD
+ * device node. Otherwise functionality is similar than in function
+ * 'ubi_attach_mtd()' where @req->mtd_num is used.
*
* Returns %0 in case of success and %-1 in case of failure (errno is set). The
@@ -252,12 +252,12 @@ int ubi_detach_mtd(libubi_t desc, const char *node, int mtd_num);
* @desc: UBI library descriptor
* @node: name of the UBI control character device node
- * @dev: path to an MTD device node
+ * @mtd_dev_node: path to an MTD device node
*
@@ -252,12 +252,12 @@ int ubi_detach_mtd(libubi_t desc, const char *node, int mtd_num);
*
- * This function detaches an MTD device @dev from UBI. Returns zero in case of
- * success and %-1 in case of failure.
+ * This function detaches an MTD device @mtd_dev_node from UBI. Returns zero in
+ * case of success and %-1 in case of failure.
*/